@@ -8,11 +8,11 @@ c = Circle((100,100), 100)
 gasp.testing.grab_screen()
 remove_from_screen(c)
 
-c = Circle((100,100), 100, filled=True, color=(50,100,150), thickness=3)
+c = Circle((100,100), 100, filled=True, color=(50,100,150))
 gasp.testing.grab_screen()
 remove_from_screen(c)
 
-c = Circle((100,100), 100, color=(50,100,150), thickness=3)
+c = Circle((100,100), 100, color=(150,100,50), thickness=5)
 gasp.testing.grab_screen()
 remove_from_screen(c)
 
